@@ -81,7 +81,7 @@ class Prior():
                    self.dists)
 
     def unit_to_physical(self, points):
-        """Transfer points from the unit hypercube to the prior volume.
+        """Convert points from the unit hypercube to physical parameters.
 
         Parameters
         ----------
@@ -100,6 +100,7 @@ class Prior():
         ------
         ValueError
             If dimensionality of `points` does not match the prior.
+
         """
         phys_points = np.zeros_like(points)
 
@@ -116,27 +117,25 @@ class Prior():
 
         return phys_points
 
-    def physical_to_structure(self, phys_points):
-        """Express points in the prior volume as a structured data type.
+    def physical_to_dictionary(self, phys_points):
+        """Convert points in the physical parameter space as a dictionary.
 
         Parameters
         ----------
         phys_points : numpy.ndarray
-            Points in the prior volume. If more than one-dimensional, each
-            row represents a point.
+            Points in the physical parameter space. If more than
+            one-dimensional, each row represents a point.
 
         Returns
         -------
-        struct_points : dict or numpy.ndarray
-            Points as a structured data type. If `phys_points` has one
-            dimension, this will be a dictionary. Otherwise, it will be a
-            structured numpy array. Each model parameter, including fixed ones,
+        param_dict : dict
+            Points as a dictionary. Each model parameter, including fixed ones,
             can be accessed via their key.
 
         Raises
         ------
         ValueError
-            If dimensionality of `points` does not match the prior.
+            If dimensionality of `phys_points` does not match the prior.
 
         """
         try:
@@ -144,23 +143,37 @@ class Prior():
         except AssertionError:
             raise ValueError('Dimensionality of points does not match prior.')
 
-        if phys_points.ndim == 1:
-            struct_points = {}
-        else:
-            struct_points = np.zeros(
-                phys_points.shape[0], dtype=[(key, float) for key in
-                                             self.keys])
+        param_dict = {}
 
         i = 0
         for key, dist in zip(self.keys, self.dists):
             if hasattr(dist, 'isf'):
-                struct_points[key] = phys_points[..., i]
+                param_dict[key] = phys_points[..., i]
                 i = i + 1
             elif isinstance(dist, numbers.Number):
-                struct_points[key] = np.ones(phys_points[..., 0].shape) * dist
+                param_dict[key] = np.ones(phys_points[..., 0].shape) * dist
 
         for key, dist in zip(self.keys, self.dists):
             if isinstance(dist, str):
-                struct_points[key] = struct_points[dist]
+                param_dict[key] = param_dict[dist]
 
-        return struct_points
+        return param_dict
+
+    def unit_to_dictionary(self, points):
+        """Convert points from the unit hypercube to a dictionary.
+
+        Parameters
+        ----------
+        points : numpy.ndarray
+            A 1-D or 2-D array containing single point or a collection of
+            points in the unit hypercube. If more than one-dimensional, each
+            row represents a point.
+
+        Returns
+        -------
+        param_dict : dict
+            Points as a dictionary. Each model parameter, including fixed ones,
+            can be accessed via their key.
+
+        """
+        return self.physical_to_dictionary(self.unit_to_physical(points))
